Enum quoted_string::error::CoreError [−][src]
pub enum CoreError {
AdvancedFailedAutomaton,
QuotedStringAlreadyEnded,
UnquoteableCharQuoted,
DoesNotStartWithDQuotes,
DoesNotEndWithDQuotes,
InvalidChar,
ZeroSizedValue,
}Variants
AdvancedFailedAutomatonQuotedStringAlreadyEndedUnquoteableCharQuotedDoesNotStartWithDQuotesDoesNotEndWithDQuotesInvalidCharZeroSizedValue
Methods
impl CoreError[src]
impl CoreErrorTrait Implementations
impl Copy for CoreError[src]
impl Copy for CoreErrorimpl Clone for CoreError[src]
impl Clone for CoreErrorfn clone(&self) -> CoreError[src]
fn clone(&self) -> CoreErrorReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0
[src]Performs copy-assignment from source. Read more
impl Eq for CoreError[src]
impl Eq for CoreErrorimpl PartialEq for CoreError[src]
impl PartialEq for CoreErrorfn eq(&self, other: &CoreError) -> bool[src]
fn eq(&self, other: &CoreError) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
fn ne(&self, other: &Rhs) -> bool1.0.0
[src]This method tests for !=.
impl Hash for CoreError[src]
impl Hash for CoreErrorfn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0
[src]Feeds a slice of this type into the given [Hasher]. Read more
impl Debug for CoreError[src]
impl Debug for CoreErrorfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Display for CoreError[src]
impl Display for CoreErrorfn fmt(&self, fter: &mut Formatter) -> Result[src]
fn fmt(&self, fter: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl StdError for CoreError[src]
impl StdError for CoreError