Enum quoted_string::spec::QuotingClass [−][src]
pub enum QuotingClass {
QText,
NeedsQuoting,
Invalid,
}Represents if a char can be contained in a quoted string and if it needs escapeing
Variants
QTextThe char can be represented in a quoted string
NeedsQuotingThe char can be represented but needs quoting (e.g. the " in r#"bla\"blo"#)
InvalidThe char is invalid (e.g. a CTL char)