Enum quoted_string::spec::State [−][src]
State used when parsing a quoted string
Variants
StartThe initial state
NormalThe normal state
FailedFailed as it e.g. hit an invalid char
QPStartstart of a quoted-pair e.g. the \ of "
Custom(T)a custom state needed for more complex quoted strings
Endthe end of the quoted string was found (this is not necessary the end of the input)