Struct quoted_string::spec::ScanAutomaton [−][src]
pub struct ScanAutomaton<T: ParsingImpl> { /* fields omitted */ }
Methods
impl<Impl> ScanAutomaton<Impl> where
Impl: ParsingImpl, [src]
impl<Impl> ScanAutomaton<Impl> where
Impl: ParsingImpl, pub fn new() -> Self[src]
pub fn new() -> Selfpub fn did_end(&self) -> bool[src]
pub fn did_end(&self) -> boolpub fn end(&mut self) -> Result<(), CoreError>[src]
pub fn end(&mut self) -> Result<(), CoreError>pub fn advance(&mut self, pcp: PartialCodePoint) -> Result<bool, CoreError>[src]
pub fn advance(&mut self, pcp: PartialCodePoint) -> Result<bool, CoreError>Trait Implementations
impl<T: Debug + ParsingImpl> Debug for ScanAutomaton<T>[src]
impl<T: Debug + ParsingImpl> Debug for ScanAutomaton<T>fn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl<T: Eq + ParsingImpl> Eq for ScanAutomaton<T>[src]
impl<T: Eq + ParsingImpl> Eq for ScanAutomaton<T>impl<T: PartialEq + ParsingImpl> PartialEq for ScanAutomaton<T>[src]
impl<T: PartialEq + ParsingImpl> PartialEq for ScanAutomaton<T>fn eq(&self, other: &ScanAutomaton<T>) -> bool[src]
fn eq(&self, other: &ScanAutomaton<T>) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &ScanAutomaton<T>) -> bool[src]
fn ne(&self, other: &ScanAutomaton<T>) -> boolThis method tests for !=.
impl<T: Hash + ParsingImpl> Hash for ScanAutomaton<T>[src]
impl<T: Hash + ParsingImpl> Hash for ScanAutomaton<T>fn hash<__HT: Hasher>(&self, state: &mut __HT)[src]
fn hash<__HT: Hasher>(&self, state: &mut __HT)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0
[src]Feeds a slice of this type into the given [Hasher]. Read more
impl<T: Clone + ParsingImpl> Clone for ScanAutomaton<T>[src]
impl<T: Clone + ParsingImpl> Clone for ScanAutomaton<T>fn clone(&self) -> ScanAutomaton<T>[src]
fn clone(&self) -> ScanAutomaton<T>Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0
[src]Performs copy-assignment from source. Read more