Enum quoted_string::test_utils::TestParsingImpl [−][src]
a parsing implementations which allows non semantic stange thinks in it for testing purpose
basically you can have a non-semantic section starting with ← ending with → which has
a number of + followed by the same number of -.
E.g. "some think \n+++---\n"
This naturally makes no sense, but is a simple way to test if the custom state is used correctly, there are some quoted string impl which need custom state as they can e.g. have non semantic soft line brakes (which are slight more complex to implement and less visible in error messages, so I used this think here)
Variants
StrangeInc(usize)StrangeDec(usize)